==> dojo-1.9.4.tgz: package/cldr/nls/zh-hant/buddhist.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"field-weekday": "週天",
	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
	"dateFormatItem-MMMEd": "M月d日E",
	"eraNarrow": [
		"佛曆"
	],
	"days-format-short": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dateFormat-long": "Gy年M月d日",
	"months-format-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"dateFormatItem-yyyyQQQ": "Gy年QQQ",
	"dayPeriods-format-wide-pm": "下午",
	"dateFormat-full": "Gy年M月d日EEEE",
	"dateFormatItem-yyyyMEd": "Gy/M/d（E）",
	"dateFormatItem-Md": "M/d",
	"field-era": "年代",
	"months-standAlone-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月"
	],
	"timeFormat-short": "ah:mm",
	"quarters-format-wide": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"timeFormat-long": "zah時mm分ss秒",
	"field-year": "年",
	"field-hour": "小時",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"timeFormat-full": "zzzzah時mm分ss秒",
	"field-day-relative+0": "今天",
	"field-day-relative+1": "明天",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"field-day-relative+2": "後天",
	"dateFormatItem-H": "H時",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"quarters-format-abbr": [
		"1季",
		"2季",
		"3季",
		"4季"
	],
	"quarters-standAlone-wide": [
		"第一季度",
		"第二季度",
		"第三季度",
		"第四季度"
	],
	"dateFormatItem-Gy": "Gy年",
	"dateFormatItem-yyyyMMMEd": "Gy年M月d日E",
	"dateFormatItem-M": "M月",
	"days-standAlone-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"dateFormatItem-yyyyMMM": "Gy年M月",
	"dateFormatItem-yyyyMMMd": "Gy年M月d日",
	"timeFormat-medium": "ah:mm:ss",
	"dateFormatItem-Hm": "H:mm",
	"quarters-standAlone-abbr": [
		"1季度",
		"2季度",
		"3季度",
		"4季度"
	],
	"eraAbbr": [
		"佛曆"
	],
	"field-minute": "分鐘",
	"field-dayperiod": "上午/下午",
	"days-standAlone-abbr": [
		"周日",
		"周一",
		"周二",
		"周三",
		"周四",
		"周五",
		"周六"
	],
	"dateFormatItem-d": "d日",
	"field-day-relative+-1": "昨天",
	"dateFormatItem-h": "ah時",
	"dateTimeFormat-long": "{1}{0}",
	"dayPeriods-format-narrow-am": "上午",
	"field-day-relative+-2": "前天",
	"dateFormatItem-MMMd": "M月d日",
	"dateFormatItem-MEd": "M/d（E）",
	"dateTimeFormat-full": "{1}{0}",
	"field-day": "日",
	"days-format-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"field-zone": "時區",
	"dateFormatItem-y": "Gy年",
	"field-year-relative+-1": "去年",
	"field-month-relative+-1": "上個月",
	"dateFormatItem-hm": "ah:mm",
	"days-format-abbr": [
		"週日",
		"週一",
		"週二",
		"週三",
		"週四",
		"週五",
		"週六"
	],
	"eraNames": [
		"佛曆"
	],
	"days-format-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dateFormatItem-yyyyMd": "Gy/M/d",
	"field-month": "月",
	"days-standAlone-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dayPeriods-format-wide-am": "上午",
	"dateFormat-short": "Gy/M/d",
	"field-second": "秒",
	"field-month-relative+0": "本月",
	"field-month-relative+1": "下個月",
	"dateFormatItem-Ed": "d日（E）",
	"field-week": "週",
	"dateFormat-medium": "Gy/M/d",
	"field-year-relative+0": "今年",
	"field-week-relative+-1": "上週",
	"dateFormatItem-yyyyM": "Gy/M",
	"field-year-relative+1": "明年",
	"dayPeriods-format-narrow-pm": "下午",
	"dateFormatItem-yyyyQQQQ": "Gy年QQQQ",
	"dateFormatItem-Hms": "H:mm:ss",
	"dateFormatItem-hms": "ah:mm:ss",
	"dateFormatItem-GyMMM": "Gy年M月",
	"dateFormatItem-yyyy": "Gy年",
	"field-week-relative+0": "本週",
	"field-week-relative+1": "下週"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/zh-hant/buddhist.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"field-second-relative+0": "現在",
	"field-weekday": "週天",
	"field-wed-relative+0": "本週三",
	"field-wed-relative+1": "下週三",
	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
	"dateFormatItem-MMMEd": "M月d日E",
	"eraNarrow": [
		"佛曆"
	],
	"field-tue-relative+-1": "上週二",
	"days-format-short": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dateFormat-long": "Gy年M月d日",
	"field-fri-relative+-1": "上週五",
	"field-wed-relative+-1": "上週三",
	"months-format-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"dateFormatItem-yyyyQQQ": "Gy年QQQ",
	"dayPeriods-format-wide-pm": "下午",
	"dateFormat-full": "Gy年M月d日EEEE",
	"dateFormatItem-yyyyMEd": "Gy/M/d（E）",
	"field-thu-relative+-1": "上週四",
	"dateFormatItem-Md": "M/d",
	"dayPeriods-format-wide-noon": "中午",
	"field-era": "年代",
	"months-standAlone-wide": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"timeFormat-short": "ah:mm",
	"quarters-format-wide": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"timeFormat-long": "ah:mm:ss [z]",
	"field-year": "年",
	"field-hour": "小時",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"field-sat-relative+0": "本週六",
	"field-sat-relative+1": "下週六",
	"timeFormat-full": "ah:mm:ss [zzzz]",
	"field-day-relative+0": "今天",
	"field-thu-relative+0": "本週四",
	"field-day-relative+1": "明天",
	"field-thu-relative+1": "下週四",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"field-day-relative+2": "後天",
	"dateFormatItem-H": "H時",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月"
	],
	"quarters-format-abbr": [
		"1季",
		"2季",
		"3季",
		"4季"
	],
	"quarters-standAlone-wide": [
		"第1季",
		"第2季",
		"第3季",
		"第4季"
	],
	"dateFormatItem-Gy": "Gy年",
	"dateFormatItem-yyyyMMMEd": "Gy年M月d日E",
	"dateFormatItem-M": "M月",
	"days-standAlone-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"dateFormatItem-yyyyMMM": "Gy年M月",
	"dateFormatItem-yyyyMMMd": "Gy年M月d日",
	"timeFormat-medium": "ah:mm:ss",
	"field-sun-relative+0": "本週日",
	"dateFormatItem-Hm": "H:mm",
	"field-sun-relative+1": "下週日",
	"quarters-standAlone-abbr": [
		"1季",
		"2季",
		"3季",
		"4季"
	],
	"eraAbbr": [
		"佛曆"
	],
	"field-minute": "分鐘",
	"field-dayperiod": "上午/下午",
	"days-standAlone-abbr": [
		"週日",
		"週一",
		"週二",
		"週三",
		"週四",
		"週五",
		"週六"
	],
	"dateFormatItem-d": "d日",
	"field-day-relative+-1": "昨天",
	"dateFormatItem-h": "ah時",
	"dayPeriods-format-narrow-am": "上午",
	"field-day-relative+-2": "前天",
	"dateFormatItem-MMMd": "M月d日",
	"dateFormatItem-MEd": "M/d（E）",
	"dateTimeFormat-full": "{1}{0}",
	"field-fri-relative+0": "本週五",
	"field-fri-relative+1": "下週五",
	"field-day": "日",
	"days-format-wide": [
		"星期日",
		"星期一",
		"星期二",
		"星期三",
		"星期四",
		"星期五",
		"星期六"
	],
	"field-zone": "時區",
	"dateFormatItem-y": "Gy年",
	"field-year-relative+-1": "去年",
	"field-month-relative+-1": "上個月",
	"dateFormatItem-hm": "ah:mm",
	"days-format-abbr": [
		"週日",
		"週一",
		"週二",
		"週三",
		"週四",
		"週五",
		"週六"
	],
	"eraNames": [
		"佛曆"
	],
	"days-format-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"dateFormatItem-yyyyMd": "Gy/M/d",
	"field-month": "月",
	"dateFormatItem-MMM": "LLL",
	"days-standAlone-narrow": [
		"日",
		"一",
		"二",
		"三",
		"四",
		"五",
		"六"
	],
	"field-tue-relative+0": "本週二",
	"field-tue-relative+1": "下週二",
	"dayPeriods-format-wide-am": "上午",
	"field-mon-relative+0": "本週一",
	"field-mon-relative+1": "下週一",
	"dateFormat-short": "Gy/M/d",
	"dayPeriods-format-narrow-noon": "中午",
	"field-second": "秒",
	"field-sat-relative+-1": "上週六",
	"field-sun-relative+-1": "上週日",
	"field-month-relative+0": "本月",
	"field-month-relative+1": "下個月",
	"dateFormatItem-Ed": "d日（E）",
	"field-week": "週",
	"dateFormat-medium": "Gy年M月d日",
	"field-year-relative+0": "今年",
	"field-week-relative+-1": "上週",
	"dateFormatItem-yyyyM": "Gy/M",
	"field-year-relative+1": "明年",
	"dayPeriods-format-narrow-pm": "下午",
	"dateFormatItem-yyyyQQQQ": "Gy年QQQQ",
	"dateFormatItem-Hms": "H:mm:ss",
	"dateFormatItem-hms": "ah:mm:ss",
	"dateFormatItem-GyMMM": "Gy年M月",
	"field-mon-relative+-1": "上週一",
	"dateFormatItem-yyyy": "Gy年",
	"field-week-relative+0": "本週",
	"field-week-relative+1": "下週"
}
//end v1.x content
);
